import * as Models from './models';
import * as Parameters from './parameters';
import { Callback } from '../callback';
import { Client } from '../clients';
export declare class ContentContentState {
    private client;
    constructor(client: Client);
    /**
     * Gets the current page status of the draft or published version of content. To specify the draft version, set the
     * parameter status to PUBLISHED, otherwise DRAFT.
     */
    getContentState<T = Models.ContentStateContainer>(parameters: Parameters.GetContentState, callback: Callback<T>): Promise<void>;
    /**
     * Gets the current page status of the draft or published version of content. To specify the draft version, set the
     * parameter status to PUBLISHED, otherwise DRAFT.
     */
    getContentState<T = Models.ContentStateContainer>(parameters: Parameters.GetContentState, callback?: never): Promise<T>;
    /**
     * Sets the content state of the content specified and creates a new version (publishes the content without changing
     * the body) of the content with the new status. The desired type of status must be allowed. There are space suggested
     * statuses and custom statuses. To specify the desired new status, one can use the id of the status or the name and
     * color of the status. If contentStateId is defined, then name and color are ignored. If contentStateId is not
     * defined, name and color will be used if provided. Firstly, we will determine if a status of this name and color
     * exists, and if it does, that this status is used. If it does not exist, and custom statuses are allowed, a custom
     * status with this name and color will be created. Color can be specified in traditional english colors (teal,
     * magenta, lavender, etc.) or as a hex string ex: #0ff0Fd.
     */
    setContentState<T = Models.ContentStateContainer>(parameters: Parameters.SetContentState, callback: Callback<T>): Promise<void>;
    /**
     * Sets the content state of the content specified and creates a new version (publishes the content without changing
     * the body) of the content with the new status. The desired type of status must be allowed. There are space suggested
     * statuses and custom statuses. To specify the desired new status, one can use the id of the status or the name and
     * color of the status. If contentStateId is defined, then name and color are ignored. If contentStateId is not
     * defined, name and color will be used if provided. Firstly, we will determine if a status of this name and color
     * exists, and if it does, that this status is used. If it does not exist, and custom statuses are allowed, a custom
     * status with this name and color will be created. Color can be specified in traditional english colors (teal,
     * magenta, lavender, etc.) or as a hex string ex: #0ff0Fd.
     */
    setContentState<T = Models.ContentStateContainer>(parameters: Parameters.SetContentState, callback?: never): Promise<T>;
    /**
     * Removes the content state of the content specified and creates a new version (publishes the content without
     * changing the body) of the content with the new status.
     */
    removeContentState<T = Models.ContentStateContainer>(parameters: Parameters.RemoveContentState, callback: Callback<T>): Promise<void>;
    /**
     * Removes the content state of the content specified and creates a new version (publishes the content without
     * changing the body) of the content with the new status.
     */
    removeContentState<T = Models.ContentStateContainer>(parameters: Parameters.RemoveContentState, callback?: never): Promise<T>;
    /** Gets a Global Timestamp of the last time the content state was updated */
    getContentStateLastUpdated<T = unknown>(parameters: Parameters.GetContentStateLastUpdated, callback: Callback<T>): Promise<void>;
    /** Gets a Global Timestamp of the last time the content state was updated */
    getContentStateLastUpdated<T = unknown>(parameters: Parameters.GetContentStateLastUpdated, callback?: never): Promise<T>;
    /** Gets content states that are available for the content to be set as. */
    getAvailableContentStates<T = Models.AvailableContentStates>(parameters: Parameters.GetAvailableContentStates, callback: Callback<T>): Promise<void>;
    /** Gets content states that are available for the content to be set as. */
    getAvailableContentStates<T = Models.AvailableContentStates>(parameters: Parameters.GetAvailableContentStates, callback?: never): Promise<T>;
}
